(svn r10736) -Fix: Correct all mispellings of 'successful'.
authorpeter1138
Mon, 30 Jul 2007 13:36:09 +0000
changeset 7868 25b9aad39e4a
parent 7867 07a2830337ce
child 7869 ce89365071ee
(svn r10736) -Fix: Correct all mispellings of 'successful'.
src/console.cpp
src/map.cpp
src/misc_gui.cpp
src/network/network_udp.cpp
src/os2.cpp
src/win32.cpp
--- a/src/console.cpp	Mon Jul 30 08:49:41 2007 +0000
+++ b/src/console.cpp	Mon Jul 30 13:36:09 2007 +0000
@@ -463,7 +463,7 @@
 /**
  * Change a string into its number representation. Supports
  * decimal and hexadecimal numbers as well as 'on'/'off' 'true'/'false'
- * @param *value the variable a successfull conversion will be put in
+ * @param *value the variable a successful conversion will be put in
  * @param *arg the string to be converted
  * @return Return true on success or false on failure
  */
@@ -517,7 +517,7 @@
  * there is a function associated with that and if so, execute it
  * @param hooks IConsoleHooks structure that will be checked
  * @param type type of hook, trigger that needs to be activated
- * @return true on a successfull execution of the hook command or if there
+ * @return true on a successful execution of the hook command or if there
  * is no hook/trigger present at all. False otherwise
  */
 static bool IConsoleHookHandle(const IConsoleHooks *hooks, IConsoleHookTypes type)
--- a/src/misc_gui.cpp	Mon Jul 30 08:49:41 2007 +0000
+++ b/src/misc_gui.cpp	Mon Jul 30 13:36:09 2007 +0000
@@ -859,7 +859,7 @@
  * The character is delete from the position the caret is at
  * @param tb Textbuf type to be changed
  * @param delmode Type of deletion, either WKC_BACKSPACE or WKC_DELETE
- * @return Return true on successfull change of Textbuf, or false otherwise
+ * @return Return true on successful change of Textbuf, or false otherwise
  */
 bool DeleteTextBufferChar(Textbuf *tb, int delmode)
 {
@@ -891,7 +891,7 @@
  * length of the string
  * @param tb Textbuf type to be changed
  * @param key Character to be inserted
- * @return Return true on successfull change of Textbuf, or false otherwise
+ * @return Return true on successful change of Textbuf, or false otherwise
  */
 bool InsertTextBufferChar(Textbuf *tb, WChar key)
 {
@@ -915,7 +915,7 @@
  * This defines where the caret will blink and the next characer interaction will occur
  * @param tb Textbuf type where navigation occurs
  * @param navmode Direction in which navigation occurs WKC_LEFT, WKC_RIGHT, WKC_END, WKC_HOME
- * @return Return true on successfull change of Textbuf, or false otherwise
+ * @return Return true on successful change of Textbuf, or false otherwise
  */
 bool MoveTextBufferPos(Textbuf *tb, int navmode)
 {
@@ -1589,7 +1589,7 @@
 				ShowErrorMessage(INVALID_STRING_ID, STR_4008_UNABLE_TO_DELETE_FILE, 0, 0);
 			} else {
 				BuildFileList();
-				/* Reset file name to current date on successfull delete */
+				/* Reset file name to current date on successful delete */
 				if (_saveload_mode == SLD_SAVE_GAME) GenerateFileName();
 			}
 
--- a/src/network/network_udp.cpp	Mon Jul 30 08:49:41 2007 +0000
+++ b/src/network/network_udp.cpp	Mon Jul 30 13:36:09 2007 +0000
@@ -44,7 +44,7 @@
 DEF_UDP_RECEIVE_COMMAND(Master, PACKET_UDP_MASTER_ACK_REGISTER)
 {
 	_network_advertise_retries = 0;
-	DEBUG(net, 2, "[udp] advertising on master server successfull");
+	DEBUG(net, 2, "[udp] advertising on master server successful");
 
 	/* We are advertised, but we don't want to! */
 	if (!_network_advertise) NetworkUDPRemoveAdvertise();
--- a/src/os2.cpp	Mon Jul 30 08:49:41 2007 +0000
+++ b/src/os2.cpp	Mon Jul 30 13:36:09 2007 +0000
@@ -173,7 +173,7 @@
  * and append this up to the maximum length (either absolute or screenlength). If maxlength
  * is zero, we don't care about the screenlength but only about the physical length of the string
  * @param tb Textbuf type to be changed
- * @return Return true on successfull change of Textbuf, or false otherwise
+ * @return Return true on successful change of Textbuf, or false otherwise
  */
 bool InsertTextBufferClipboard(Textbuf *tb)
 {
--- a/src/win32.cpp	Mon Jul 30 08:49:41 2007 +0000
+++ b/src/win32.cpp	Mon Jul 30 13:36:09 2007 +0000
@@ -1016,7 +1016,7 @@
  * and append this up to the maximum length (either absolute or screenlength). If maxlength
  * is zero, we don't care about the screenlength but only about the physical length of the string
  * @param tb Textbuf type to be changed
- * @return true on successfull change of Textbuf, or false otherwise
+ * @return true on successful change of Textbuf, or false otherwise
  */
 bool InsertTextBufferClipboard(Textbuf *tb)
 {
--- a/src/map.cpp	Mon Jul 30 08:49:41 2007 +0000
+++ b/src/map.cpp	Mon Jul 30 13:36:09 2007 +0000
@@ -282,7 +282,7 @@
 		n = 2;
 		if (proc(TileXY(x, y), data)) return true;
 
 		/* If tile test is not successfull, get one tile down and left,
 		 * ready for a test in first circle around center tile */
 		x += _tileoffs_by_dir[DIR_W].x;
 		y += _tileoffs_by_dir[DIR_W].y;
@@ -300,7 +300,7 @@
 			uint j;
 			for (j = n; j != 0; j--) {
 				if (x <= MapMaxX() && y <= MapMaxY() && ///< Is the tile within the map?
-						proc(TileXY(x, y), data)) {     ///< Is the callback successfulll?
+						proc(TileXY(x, y), data)) {     ///< Is the callback successful?
 					return true;                        ///< then stop the search
 				}
 
@@ -282,7 +282,7 @@
 		if (proc(TileXY(x, y), data)) return true;
 
-		/* If tile test is not successfull, get one tile down and left,
+		/* If tile test is not successful, get one tile down and left,
 		 * ready for a test in first circle around center tile */
 		x += _tileoffs_by_dir[DIR_W].x;